@@ -158,33 +158,46 @@ if(family=="multinomial"){
       a0=matrix(fit$a0[seq(lmu*nc)],nc,lmu,dimnames=list(classnames,stepnames))
       a0=scale(a0,TRUE,FALSE)
       attr(a0,"scaled:center")=NULL
-    dfmat=a0
-    ca=array(fit$ca[seq(nx*lmu*nc)],c(nx,nc,lmu))[seq(ninmax),,,drop=FALSE]
-    ia=fit$ia[seq(ninmax)]
-    ja=rep(fit$ia[seq(ninmax)],lmu)
-    ia=cumsum(c(1,rep(ninmax,lmu)))
-    df=apply(abs(ca)>0,c(1,3),any)
-    df=apply(df,2,sum)
-    dd=c(nvars,lmu)
-     for(k in seq(nc)){
-      cak=ca[,k, ]
-      dfmat[k,]=apply(abs(cak)>0,2,sum)
-      beta=new("dgCMatrix",Dim=dd,Dimnames=list(vnames,stepnames),x=as.vector(cak),p=as.integer(ia-1),i=as.integer(ja-1))
-      beta.list[[k]]=beta
+      dfmat=a0
+      dd=c(nvars,lmu)
+      if(ninmax>0){
+        ca=array(fit$ca[seq(nx*lmu*nc)],c(nx,nc,lmu))[seq(ninmax),,,drop=FALSE]
+        ia=fit$ia[seq(ninmax)]
+        ja=rep(fit$ia[seq(ninmax)],lmu)
+        ia=cumsum(c(1,rep(ninmax,lmu)))
+        df=apply(abs(ca)>0,c(1,3),any)
+        df=apply(df,2,sum)
+        for(k in seq(nc)){
+          cak=ca[,k, ,drop=FALSE]
+          dfmat[k,]=apply(abs(cak)>0,2,sum)
+          beta=new("dgCMatrix",Dim=dd,Dimnames=list(vnames,stepnames),x=as.vector(cak),p=as.integer(ia-1),i=as.integer(ja-1))
+          beta.list[[k]]=beta
+        }
+   } else{
+    for (k in seq(nc)) {
+      dfmat[k, ] = rep(0,lmu)
+      beta.list[[k]] = zeromat(nvars,lmu,vnames,stepnames)
     }
+  }
+       
     outlist=list(a0=a0,beta=beta.list,
          dev=fit$dev[seq(lmu)],nulldev=nulldev,dfmat=dfmat,df=df,
          lambda=lam,npasses=fit$nlp,jerr=fit$jerr,dim=dd,call=this.call)
     class(outlist)=c("glmnet","multnet")
     }
      else{
-           ca=matrix(fit$ca[seq(nx*lmu)],nx,lmu)[seq(ninmax),]
+           dd=c(nvars,lmu)
+    if(ninmax>0){
+           ca=matrix(fit$ca[seq(nx*lmu)],nx,lmu)[seq(ninmax),,drop=FALSE]
            df=apply(abs(ca)>0,2,sum)
            ia=fit$ia[seq(ninmax)]
            ja=rep(fit$ia[seq(ninmax)],lmu)
            ia=cumsum(c(1,rep(ninmax,lmu)))
-           dd=c(nvars,lmu)
            beta=new("dgCMatrix",Dim=dd,Dimnames=list(vnames,stepnames),x=as.vector(ca),p=as.integer(ia-1),i=as.integer(ja-1))
+         }else {
+           beta = zeromat(nvars,lmu,vnames,stepnames)
+           df=rep(0,lmu)
+         }
 
       if(family=="binomial"){
           a0=-fit$a0[seq(lmu)]
